.. Ethereum ABI Utils documentation master file, created by
   sphinx-quickstart on Fri Feb 19 14:30:29 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Ethereum ABI Utils's documentation!
==============================================

This provides relatively low-level python utilities for encoding data
using Ethereum ABI definitiens.

Table of Contents
========================

.. toctree::
    :maxdepth: 1

    overview
    encoding
    decoding
    nested_dynamic_arrays
    eth_abi
    releases


Indices and tables
------------------

* :ref:`API Glossary <genindex>`
* :ref:`modindex`
